==> kmplayer-0.8.4-rc3.tar.bz2: kmplayer-0.8.4-rc3/src/kmplayer_callback.h <==
/**
 * Copyright (C) 2003 by Koos Vriezen <koos ! vriezen () xs4all ! nl>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#ifndef _KMPLAYER_CALLBACK_H_
#define _KMPLAYER_CALLBACK_H_

#include <dcopobject.h>

class KMPlayerCallbackProcess;

class KMPlayerCallback : public DCOPObject {
    K_DCOP
public:
    enum StatusCode { stat_addurl = 0, stat_newtitle };
    KMPlayerCallback (KMPlayerCallbackProcess *);
k_dcop:
    ASYNC statusMessage (int code, QString msg);
    ASYNC errorMessage (int code, QString msg);
    ASYNC finished ();
    ASYNC playing ();
    ASYNC started (QByteArray data);
    ASYNC movieParams (int length, int width, int height, float aspect);
    ASYNC moviePosition (int position);
    ASYNC loadingProgress (int percentage);
private:
    KMPlayerCallbackProcess * m_process;
};

#endif //_KMPLAYER_CALLBACK_H_

==> kmplayer-0.9.1.tar.bz2: kmplayer-0.9.1/src/kmplayer_callback.h <==
/**
 * Copyright (C) 2003 by Koos Vriezen <koos ! vriezen () xs4all ! nl>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#ifndef _KMPLAYER_CALLBACK_H_
#define _KMPLAYER_CALLBACK_H_

#include <dcopobject.h>
#include <qstringlist.h>

namespace KMPlayer {

class CallbackProcess;

class Callback : public DCOPObject {
    K_DCOP
public:
    enum StatusCode { stat_addurl = 0, stat_newtitle };
    Callback (CallbackProcess *);
k_dcop:
    ASYNC statusMessage (int code, QString msg);
    ASYNC errorMessage (int code, QString msg);
    ASYNC finished ();
    ASYNC playing ();
    ASYNC started (QCString dcopname, QByteArray data);
    ASYNC movieParams (int length, int width, int height, float aspect, QStringList alang, QStringList slang);
    ASYNC moviePosition (int position);
    ASYNC loadingProgress (int percentage);
private:
    CallbackProcess * m_process;
};

} // namespace

#endif //_KMPLAYER_CALLBACK_H_
